@@ -3,10 +3,10 @@
 
 __author__ = 'Ben Lopatin'
 __email__ = 'ben@wellfire.co'
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
-from client import GeocodioClient
-from data import Address, Location, LocationCollection
+from .client import GeocodioClient
+from .data import Address, Location, LocationCollection
 
 __all__ = [GeocodioClient, Address, Location, LocationCollection]
